==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Imprimir");
define("_FRIEND","Envie este artigo a um amigo");
define("_ARTICLES","Artigos");
define("_USCORE","Pontuao");
define("_DATE","Data");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Stories_Archive/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","Imprimir");
define("_FRIEND","Envie este artigo a um amigo");
define("_ARTICLES","Artigos");
define("_USCORE","Pontuao");
define("_DATE","Data");
define("_SELECTMONTH2VIEW","Please select the month you want to view:");
define("_SHOWALLSTORIES","Show ALL Stories");
define("_STORIESARCHIVE","Stories Archive");
define("_ACTIONS","Actions");
define("_ARCHIVESINDEX","Stories Archive Index");
define("_ALLSTORIESARCH","All Stories");
define("_NEXTPAGE","Next Page");
define("_PREVIOUSPAGE","Previous Page");

?>
